@@ -1,12 +1,12 @@
 # SPDX-License-Identifier: BSD-3-Clause
-# Copyright (c) 2022 Scipp contributors (https://github.com/scipp)
+# Copyright (c) 2023 Scipp contributors (https://github.com/scipp)
 # @author Simon Heybrock
 
-from ..core import DataArray, BinEdgeError, DimensionError, VariancesError
-
 from functools import wraps
 from typing import Callable, Union
 
+from ..core import BinEdgeError, DataArray, DimensionError, VariancesError
+
 
 def _validated_masks(da, dim):
     masks = {}
