@@ -1,12 +1,12 @@
 # SPDX-License-Identifier: BSD-3-Clause
-# Copyright (c) 2022 Scipp contributors (https://github.com/scipp)
+# Copyright (c) 2023 Scipp contributors (https://github.com/scipp)
 
 from __future__ import annotations
 
-from typing import Union, TYPE_CHECKING
+from typing import TYPE_CHECKING, Union
 from warnings import warn
 
-from ..core import Dataset, DataArray, Unit, Variable, scalar
+from ..core import DataArray, Dataset, Unit, Variable, scalar
 from ..typing import VariableLike
 from ..units import default_unit
 
