@@ -1,17 +1,18 @@
 # SPDX-License-Identifier: BSD-3-Clause
-# Copyright (c) 2022 Scipp contributors (https://github.com/scipp)
+# Copyright (c) 2023 Scipp contributors (https://github.com/scipp)
 # @author Simon Heybrock
-from typing import Callable, Dict, Literal, Optional, Union, Tuple
 import warnings
+from typing import Callable, Dict, Literal, Optional, Tuple, Union
 
 from .._scipp import core as _cpp
+from ..typing import Dims, MetaDataMap, VariableLike
 from ._cpp_wrapper_util import call_func as _call_cpp_func
-from ..typing import Dims, VariableLike, MetaDataMap
-from .domains import merge_equal_adjacent
-from .operations import islinspace
-from .math import midpoints
-from .shape import concat
 from .bin_remapping import concat_bins
+from .data_group import DataGroup
+from .domains import merge_equal_adjacent
+from .math import midpoints
+from .operations import islinspace
+from .shape import concat
 
 
 class Lookup:
@@ -156,11 +157,19 @@ class Bins:
                 start = self._obj.bins.meta[dim].min()
             if stop is None:
                 stop = _upper_bound(self._obj.bins.meta[dim].max())
+
             if not (isinstance(start, _cpp.Variable)
                     and isinstance(stop, _cpp.Variable)):
                 raise ValueError(
                     "Bins can only by sliced using label-based indexing. Expected "
                     f"start and stop to be scipp.Variable, got '{start}' and '{stop}'.")
+
+            if start > stop:
+                if index.start is None:
+                    start = stop
+                elif index.stop is None:
+                    stop = start
+
             return self._obj.bin({dim: concat([start, stop], dim)}).squeeze(dim)
         raise ValueError(
             f"Unsupported key '{key}'. Expected a dimension label and "
@@ -455,7 +464,8 @@ def _bins(obj):
 
 def _set_bins(obj, bins: Bins):
     # Should only be used by __iadd__ and friends
-    assert obj is bins._obj
+    if obj is not bins._obj:
+        raise ValueError("Cannot set bins with a new object")
 
 
 def _groupby_bins(obj):
@@ -505,6 +515,8 @@ def bins(*,
         For creating DataArrays based on binning of coord value
         instead of explicitly given index ranges.
     """
+    if any([isinstance(x, DataGroup) for x in [begin, end, data]]):
+        raise ValueError("`scipp.bins` does not support DataGroup arguments.")
     return _call_cpp_func(_cpp.bins, begin, end, dim, data)
 
 
@@ -527,7 +539,8 @@ def bins_like(x: VariableLike, fill_value: _cpp.Variable) -> _cpp.Variable:
     :
         Variable containing fill value in bins.
     """
-
+    if isinstance(x, DataGroup) or isinstance(fill_value, DataGroup):
+        raise ValueError("`scipp.bins_like` does not support DataGroup arguments.")
     var = x
     if not isinstance(x, _cpp.Variable):
         var = var.data
