@@ -1,5 +1,5 @@
 # SPDX-License-Identifier: BSD-3-Clause
-# Copyright (c) 2022 Scipp contributors (https://github.com/scipp)
+# Copyright (c) 2023 Scipp contributors (https://github.com/scipp)
 # @author Simon Heybrock
 # flake8: noqa: E501
 
@@ -7,6 +7,7 @@ from __future__ import annotations
 
 from .._scipp import core as _cpp
 from ..typing import VariableLike
+from . import data_group
 from ._cpp_wrapper_util import call_func as _call_cpp_func
 from .variable import scalar
 
@@ -143,10 +144,7 @@ def not_equal(x: VariableLike, y: VariableLike) -> VariableLike:
     return _call_cpp_func(_cpp.not_equal, x, y)
 
 
-def identical(x: VariableLike,
-              y: VariableLike,
-              *,
-              equal_nan: bool = False) -> VariableLike:
+def identical(x: VariableLike, y: VariableLike, *, equal_nan: bool = False) -> bool:
     """Full comparison of x and y.
 
     Parameters
@@ -165,6 +163,14 @@ def identical(x: VariableLike,
         True if x and y have identical values, variances, dtypes, units,
         dims, shapes, coords, and masks. Else False.
     """
+    if isinstance(x, data_group.DataGroup):
+        if not isinstance(y, data_group.DataGroup):
+            raise TypeError("Both or neither of the arguments must be a DataGroup")
+        if x.keys() != y.keys():
+            return False
+        results = data_group._data_group_binary(identical, x, y, equal_nan=equal_nan)
+        return all(results.values())
+
     return _call_cpp_func(_cpp.identical, x, y, equal_nan=equal_nan)
 
 
