@@ -1,12 +1,12 @@
 # SPDX-License-Identifier: BSD-3-Clause
-# Copyright (c) 2022 Scipp contributors (https://github.com/scipp)
+# Copyright (c) 2023 Scipp contributors (https://github.com/scipp)
 # @author Simon Heybrock
 from typing import Dict, Optional
 
-from .._scipp.core import Variable, DataArray, Dataset, CoordError
+from .._scipp.core import CoordError, DataArray, Dataset, Variable
 from ..typing import VariableLikeType
 from .bins import bins
-from .dataset import merge
+from .operations import merge
 
 
 def _combine_dims(dims_dict: Optional[Dict[str, str]],
