@@ -1,7 +1,7 @@
 # SPDX-License-Identifier: BSD-3-Clause
-# Copyright (c) 2022 Scipp contributors (https://github.com/scipp)
+# Copyright (c) 2023 Scipp contributors (https://github.com/scipp)
 # @author Simon Heybrock
-from .._scipp.core import _element_keys, _get_elements, _set_elements, DType
+from .._scipp.core import DType, _element_keys, _get_elements, _set_elements
 
 
 def _prop(key):
