@@ -1,9 +1,10 @@
 # SPDX-License-Identifier: BSD-3-Clause
-# Copyright (c) 2022 Scipp contributors (https://github.com/scipp)
+# Copyright (c) 2023 Scipp contributors (https://github.com/scipp)
 # @author Simon Heybrock
 from typing import Dict
-from .cpp_classes import DataArray, Variable, Dataset
+
 from ..typing import VariableLikeType
+from .cpp_classes import DataArray, Dataset, Variable
 from .like import empty_like
 
 
@@ -32,3 +33,14 @@ def copy_for_overwrite(obj: VariableLikeType) -> VariableLikeType:
                              masks=_copy_dict_for_overwrite(da.masks),
                              attrs=_copy_dict_for_overwrite(da.attrs))
     return ds
+
+
+class VisibleDeprecationWarning(UserWarning):
+    """Visible deprecation warning.
+
+    By default, Python and in particular Jupyter will not show deprecation
+    warnings, so this class can be used when a very visible warning is helpful.
+    """
+
+
+VisibleDeprecationWarning.__module__ = 'scipp'
