@@ -1,10 +1,9 @@
 # SPDX-License-Identifier: BSD-3-Clause
-# Copyright (c) 2022 Scipp contributors (https://github.com/scipp)
+# Copyright (c) 2023 Scipp contributors (https://github.com/scipp)
 # @author Simon Heybrock
 from functools import lru_cache
 
-from ..core import array, linspace, ones
-from ..core import DataArray
+from ..core import DataArray, array, linspace, ones
 from ..io import open_hdf5
 
 _version = '1'
