@@ -1,12 +1,12 @@
 # SPDX-License-Identifier: BSD-3-Clause
-# Copyright (c) 2022 Scipp contributors (https://github.com/scipp)
+# Copyright (c) 2023 Scipp contributors (https://github.com/scipp)
 # @file
 # @author Dimitar Tasev
 
 from __future__ import annotations
 
-from ..typing import VariableLike
 from ..core import Variable
+from ..typing import VariableLike
 from .table import table  # noqa: F401
 
 
@@ -53,5 +53,5 @@ def to_html(container: VariableLike):
         Create HTML representation without showing it.
         Works outside of notebooks.
     """
-    from IPython.display import display, HTML
+    from IPython.display import HTML, display
     display(HTML(make_html(container)))
