@@ -1,5 +1,5 @@
 # SPDX-License-Identifier: BSD-3-Clause
-# Copyright (c) 2022 Scipp contributors (https://github.com/scipp)
+# Copyright (c) 2023 Scipp contributors (https://github.com/scipp)
 # @file
 # @author Simon Heybrock
 from .html import make_html
@@ -7,6 +7,7 @@ from .html import make_html
 
 def _repr_html_():
     import inspect
+
     # Is there a better way to get the scope? The `7` is hard-coded for the
     # current IPython stack when calling _repr_html_ so this is bound to break.
     scope = inspect.stack()[7][0].f_globals
@@ -18,9 +19,9 @@ def _repr_html_():
         out += f"<details open=\"open\"><summary>{category}s:"\
                f"({len(names)})</summary>"
         for name in names:
-            html = make_html(eval(name, scope))
+            html = make_html(eval(name, scope))  # nosec: B307
             out += f"<details style=\"padding-left:2em\"><summary>"\
                    f"{name}</summary>{html}</details>"
         out += "</details>"
-    from IPython.core.display import display, HTML
+    from IPython.core.display import HTML, display
     display(HTML(out))
