@@ -1,12 +1,15 @@
 # SPDX-License-Identifier: BSD-3-Clause
-# Copyright (c) 2022 Scipp contributors (https://github.com/scipp)
+# Copyright (c) 2023 Scipp contributors (https://github.com/scipp)
 # @file
 # @author Neil Vaytet
+import warnings
 
+from .. import config
+from ..core.util import VisibleDeprecationWarning
 from .tools import is_static
 
 
-def plot(*args, **kwargs):
+def legacy_plot(*args, **kwargs):
     """
     Plot a Scipp object.
 
@@ -136,7 +139,16 @@ def plot(*args, **kwargs):
     :type vmax: float, optional
 
     """
+    warnings.warn(
+        "You are using Scipp's deprecated plotting backend. "
+        "This will be removed in Scipp v23.08.0 (August 2023) or after. "
+        "Scipp v23.03.0 (March 2023) and all later versions will use Plopp by default. "
+        "See https://scipp.github.io/visualization/plotting-overview.html#Migrating-to-the-new-backend "  # noqa
+        "for details and a migration guide.",
+        VisibleDeprecationWarning)
+
     import matplotlib.pyplot as plt
+
     from .wrapper import plot as _plot
 
     # Switch auto figure display off for better control over when figures are
@@ -156,3 +168,11 @@ def plot(*args, **kwargs):
         plt.ion()
 
     return output
+
+
+def plot(*args, **kwargs):
+    if config['plot'].get('use_plopp'):
+        import plopp
+        return plopp.plot(*args, **kwargs)
+    else:
+        return legacy_plot(*args, **kwargs)
