@@ -1,7 +1,7 @@
 # SPDX-License-Identifier: BSD-3-Clause
-# Copyright (c) 2022 Scipp contributors (https://github.com/scipp)
-from .view1d import PlotView1d
+# Copyright (c) 2023 Scipp contributors (https://github.com/scipp)
 from .resampling_model import ResamplingMode
+from .view1d import PlotView1d
 
 
 class MarkerModel:
@@ -279,7 +279,9 @@ class PlotController:
             visible = False
             self.widgets.clear_profile_button()
         else:
-            assert len(dims) == 1  # TODO support 2d profiles
+            if len(dims) != 1:
+                raise NotImplementedError(
+                    "Profile view only supports 1-dimensional data")
             if owner.button_style == "info":
                 owner.button_style = ""
                 visible = False
