@@ -1,14 +1,16 @@
 # SPDX-License-Identifier: BSD-3-Clause
-# Copyright (c) 2022 Scipp contributors (https://github.com/scipp)
+# Copyright (c) 2023 Scipp contributors (https://github.com/scipp)
 # @file
 # @author Neil Vaytet
 
 import typing as _std_typing
 
+import numpy as np
 import numpy.typing
 
 from ._scipp import core as sc
 from .core.cpp_classes import DataArray, Dataset, DType, Variable
+from .core.data_group import DataGroup
 
 
 def is_scalar(obj: _std_typing.Any) -> bool:
@@ -54,12 +56,14 @@ Can be a string (for a single dimension) or a sequence of strings (multiple dime
 A value of ``None`` indicates "all dimensions."
 """
 
-VariableLike = _std_typing.Union[Variable, DataArray, Dataset]
+VariableLike = _std_typing.Union[Variable, DataArray, Dataset, DataGroup]
 """Any object that behaves like a :class:`scipp.Variable`.
 
-More concretely, an array with labeled dimensions:
+More concretely, an array with labeled dimensions which supports slicing and
+arithmetic:
 
 - :class:`scipp.DataArray`
+- :class:`scipp.DataGroup`
 - :class:`scipp.Dataset`
 - :class:`scipp.Variable`
 """
@@ -67,7 +71,8 @@ More concretely, an array with labeled dimensions:
 MetaDataMap = _std_typing.MutableMapping[str, Variable]
 """dict-like object mapping dimension labels to Variables."""
 
-VariableLikeType = _std_typing.TypeVar('VariableLikeType', Variable, DataArray, Dataset)
+VariableLikeType = _std_typing.TypeVar('VariableLikeType', Variable, DataArray, Dataset,
+                                       DataGroup)
 """TypeVar for use in annotations.
 
 Should be hidden in rendered documentation in favor of VariableLike.
@@ -87,3 +92,17 @@ This includes
   - :class:`type` objects like :class:`int` and :class:`float`
   - names of dtypes as strings like ``'int32'`` and ``'float64'``
 """  # noqa: E501
+
+if _std_typing.TYPE_CHECKING:
+    from enum import Enum
+
+    class ellipsis(Enum):
+        Ellipsis = "..."
+else:
+    ellipsis = type(Ellipsis)
+
+ScippIndex = _std_typing.Union[ellipsis, int, tuple, slice, list, np.ndarray,
+                               _std_typing.Tuple[str,
+                                                 _std_typing.Union[int, slice, list,
+                                                                   np.ndarray,
+                                                                   Variable]], Variable]
